Welcome to Teatime's documentation!
======================================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    readme
    installation
    usage
    architecture
    modules
    contributing
    authors
    history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
